@@ -8,7 +8,7 @@ from linkcheck.linkcheck_settings import MAX_CHECKS_PER_RUN
 class Command(BaseCommand):
     option_list = BaseCommand.option_list + (
         make_option('--externalinterval', '-e', type='int',
-            help='Specifies the length of time in seconds until external links are rechecked. Defaults to linkcheck_config setting'),
+            help='Specifies the length of time in minutes until external links are rechecked. Defaults to linkcheck_config setting'),
         make_option('--limit', '-l', type='int',
             help='Specifies the maximum number (int) of links to be checked. Defaults to linkcheck_config setting.  Value less than 1 will check all'),
     )
@@ -25,7 +25,7 @@ class Command(BaseCommand):
         else:
             limit = MAX_CHECKS_PER_RUN
 
-        print "Checking all external links that haven't been tested for %s seconds." % externalinterval
+        print "Checking all external links that haven't been tested for %s minutes." % externalinterval
         if limit!=-1:
             print "Will run maximum of %s checks this run." % limit
 
